/*
 * Copyright 2020 Red Hat, Inc. and/or its affiliates
 * and other contributors as indicated by the @author tags.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.as.galleon.maven.repo.patcher;

import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;

/**
 * Patch a repo and generate galleon patches for updated artifacts.
 *
 * @author jdenise
 */
public final class Main {

    public static void main(String[] args) throws Exception {
        if (args.length != 3) {
            throw new Exception("Error, 3 arguments expected: zipped repo, zipped repo patch, generated zipped repo file name");
        }
        Path originalMavenRepo = Paths.get(args[0]);
        Path repoPatch = Paths.get(args[1]);

        if (!Files.exists(originalMavenRepo)) {
            throw new Exception("Original repo doesn't exist");
        }

        if (!Files.exists(repoPatch)) {
            throw new Exception("Repo patch doesn't exist");
        }

        Path outputFile = Paths.get(args[2]);

        new Patcher(originalMavenRepo, repoPatch, outputFile).patch();
    }
}
